from setuptools import setup

setup(name='stat_prob_distributions',
      version='0.1',
      description='Gaussian  and Binomial distributions',
      packages=['stat_prob_distributions'],
      zip_safe=False)
